{-----------------------------------------------------------------------------
The contents of this file are subject to the Mozilla Public License
Version 1.1 (the "License"); you may not use this file except in compliance
with the License. You may obtain a copy of the License at
http://www.mozilla.org/MPL/MPL-1.1.html

Software distributed under the License is distributed on an "AS IS" basis,
WITHOUT WARRANTY OF ANY KIND, either expressed or implied. See the License for
the specific language governing rights and limitations under the License.

The Original Code is: JvRecycleBin.PAS, released on 2004-03-11.

The Initial Developer of the Original Code is Stefano Pessina [pessina@tntdeveloping.com]
Portions created by Stefano Pessina are Copyright (C) 2004 Stefano Pessina.
All Rights Reserved.

Contributor(s):

Last Modified: 2004-03-11

You may retrieve the latest version of this file at the Project JEDI's JVCL home page,
located at http://jvcl.sourceforge.net

Known Issues:
-----------------------------------------------------------------------------}

{$I jvcl.inc}

{ A unit that allow to handle the Recycle Bin. }

unit JvRecycleBin;

interface

uses
  Windows, Dialogs, SysUtils, Messages, Classes, Graphics, Controls,
  JvComponent;

type
  TJvRecycleBin = class(TJvGraphicControl)
  private
    FConfirm: Boolean;
    FProgress: Boolean;
    FSound: Boolean;
    FBmp: TBitmap;
  protected
    procedure Paint; override;
  public
    constructor Create(AOwner: TComponent); override;
    destructor Destroy; override;
    procedure SetBounds(ALeft: Integer; ATop: Integer; AWidth: Integer;
      AHeight: Integer); override;
    procedure Empty();
  published
    property Confirm: Boolean read FConfirm write FConfirm default True;
    property Progress: Boolean read FProgress write FProgress default False;
    property Sound: Boolean read FSound write FSound default False;
  end;
procedure Register;

implementation

uses
  Forms, StdCtrls;
  
{$IFDEF MSWINDOWS}
//{$R ..\Resources\JvRecycleBin.res}
{$R JvRecycleBin.res}
{$ENDIF MSWINDOWS}
{$IFDEF LINUX}
//{$R ../Resources/JvRecycleBin.res}
{$R JvRecycleBin.res}
{$ENDIF LINUX}

//To comment by including in JVCL Project
procedure Register;
begin
  RegisterComponents('JvRecycleBin', [TJvRecycleBin]);
end;

procedure TJvRecycleBin.Empty;
const
 SHERB_NOCONFIRMATION = $00000001 ;
 SHERB_NOPROGRESSUI = $00000002 ;
 SHERB_NOSOUND = $00000004 ;
type
 TSHEmptyRecycleBin = function (Wnd:HWND; pszRootPath:PChar; dwFlags:DWORD):HRESULT; stdcall;
var
 SHEmptyRecycleBin : TSHEmptyRecycleBin;
 LibHandle : THandle;
begin
 LibHandle := LoadLibrary(PChar('Shell32.dll')) ;
 if LibHandle <> 0 then
  @SHEmptyRecycleBin := GetProcAddress(LibHandle, 'SHEmptyRecycleBinA')
 else
 begin
  MessageDlg('Unabled to load Shell32.dll.', mtError, [mbOK], 0);
  Exit;
 end;

 if @SHEmptyRecycleBin <> nil then
 begin
  if Confirm = true and Progress = true and Sound = true then
   SHEmptyRecycleBin(Application.Handle,nil,0)
  else if Confirm = false and Progress = true and Sound = true then
   SHEmptyRecycleBin(Application.Handle,nil,SHERB_NOCONFIRMATION)
  else if Confirm = false and Progress = false and Sound = true then
   SHEmptyRecycleBin(Application.Handle,nil,SHERB_NOCONFIRMATION or SHERB_NOPROGRESSUI)
  else if Confirm = false and Progress = false and Sound = false then
   SHEmptyRecycleBin(Application.Handle,nil,SHERB_NOCONFIRMATION or SHERB_NOPROGRESSUI or SHERB_NOSOUND)
  else if Confirm = true and Progress = true and Sound = false then
   SHEmptyRecycleBin(Application.Handle,nil,SHERB_NOSOUND)
  else if Confirm = true and Progress = false and Sound = false then
   SHEmptyRecycleBin(Application.Handle,nil,SHERB_NOPROGRESSUI or SHERB_NOSOUND)
  else if Confirm = false and Progress = true and Sound = false then
   SHEmptyRecycleBin(Application.Handle,nil,SHERB_NOCONFIRMATION or SHERB_NOSOUND)
 end;
 FreeLibrary(LibHandle);
 @SHEmptyRecycleBin := nil ;
end;

constructor TJvRecycleBin.Create(AOwner: TComponent);
begin
  inherited Create(AOwner);
  ControlStyle := ControlStyle + [csNoStdEvents, csFixedHeight, csFixedWidth];
  FConfirm := True;
  FProgress := False;
  FSound := False;
  if csDesigning in ComponentState then
  begin
    FBmp := TBitmap.Create;
    FBmp.LoadFromResourceName(hInstance, 'DESIGNRECYCLEBIN');
  end
  else
    Visible := False;
end;

destructor TJvRecycleBin.Destroy;
begin
  FBmp.Free;
  inherited Destroy;
end;

procedure TJvRecycleBin.Paint;
begin
  if not (csDesigning in ComponentState) then
    Exit;
  Canvas.Brush.Color := clBtnFace;
  inherited Canvas.BrushCopy(ClientRect, FBmp, ClientRect, clFuchsia);
end;

procedure TJvRecycleBin.SetBounds(ALeft, ATop, AWidth, AHeight: Integer);
begin
  inherited SetBounds(ALeft, ATop, 28, 28);
end;

end.

